import psutil


def 进程_取进程列表() -> list[str]:
    """
    获取系统中全部运行中进程的名称列表。

    功能说明：
        - 返回结果中可能包含重复进程名，因为系统中可能存在多个同名实例。
        - 读取失败时返回空列表。

    Returns:
        list[str]: 成功返回进程名称列表；失败返回空列表。
    """
    try:
        return [进程对象.info['name'] for 进程对象 in psutil.process_iter(['name']) if 进程对象.info['name']]
    except Exception:
        return []