import psutil


def PID_取程序路径(pid: int | str) -> str:
    """
    根据进程 PID 获取程序可执行文件路径。

    功能说明：
        - 当 PID 不存在、无权限访问、参数无效或发生异常时，返回空字符串。

    Args:
        pid (int | str): 要查询的进程 PID。

    Returns:
        str: 成功返回程序路径；失败返回空字符串。
    """
    try:
        pid = int(pid)
        return psutil.Process(pid).exe()
    except Exception:
        return ''
